#ifndef UTILCONF_H
#define UTILCONF_H

#include <defs.h>
SWORD_NAMESPACE_START
char getconfent (char *filename, char *entryname, char *buf, int len);
SWORD_NAMESPACE_END

#endif
